#!/bin/bash
shopt -s nullglob

DISPLAY_NAME='TNS Backup'
DEFAULT_URL='"https://texomans.net:8060/"'
ALLOW_BLANK="false"
PREV_SAVED_MSG=""

EMPTY_URL_TEXT="${DEFAULT_URL}"
EMPTY_USERNAME_TEXT=""
EMPTY_PASSWORD_TEXT=""

CONFIG_DIR="${HOME:-/root}"
if [[ $SYNOPKG_DSM_VERSION_MAJOR -eq 7 ]]; then
  # at the time this is run on DSM 7, there is no symlink at a known location for us to check
  # so instead, try to find our data share on any volume
  for share in /volume*/backuptool; do
    CONFIG_DIR="${share}"
    break
  done
fi

if [[ -f "${CONFIG_DIR}/.config/backup-tool/config.dat" ]]; then
  # there are existing credentials
  ALLOW_BLANK="true"
  DEFAULT_URL='""'
  PREV_SAVED_MSG=" (leave blank to use saved)"
  EMPTY_USERNAME_TEXT="(use saved)"
  EMPTY_PASSWORD_TEXT="(use saved)"
fi

cat <<EOF > "${SYNOPKG_TEMP_LOGFILE}"
[{
    "step_title": "${DISPLAY_NAME} authentication",
    "items": [{
        "type": "textfield",
        "subitems": [{
            "key": "backuptool_server",
            "desc": "Server${PREV_SAVED_MSG}",
            "defaultValue": ${DEFAULT_URL},
            "emptyText": ${EMPTY_URL_TEXT},
            "validator": {
                "allowBlank": ${ALLOW_BLANK},
                "regex": "/^https?:\\\\/\\\\/\\\\S+\$/i"
            }
        }]
    }, {
        "type": "textfield",
        "subitems": [{
            "key": "backuptool_username",
            "desc": "Username${PREV_SAVED_MSG}",
            "emptyText": "${EMPTY_USERNAME_TEXT}",
            "validator": {
                "allowBlank": ${ALLOW_BLANK}
            }
        }]
    }, {
        "type": "password",
        "subitems": [{
            "key": "backuptool_password",
            "desc": "Password${PREV_SAVED_MSG}",
            "emptyText": "${EMPTY_PASSWORD_TEXT}",
            "validator": {
                "allowBlank": ${ALLOW_BLANK}
            }
        }]
    }]
}]
EOF
